% vim:ft=tex:ts=2:sw=2
%
% Casper Ti. Vector's biblatex style
%
% Copyright (c) 2012-2014 Casper Ti. Vector
%
% This work may be distributed and/or modified under the conditions of the
% LaTeX Project Public License, either version 1.3 of this license or (at
% your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX version
% 2005/12/01 or later.
%
% This work has the LPPL maintenance status `maintained'.
% The current maintainer of this work is Casper Ti. Vector.
%
% This work consists of the following files:
%   caspervector.bbx
%   caspervector.cbx
%   biblatex-caspervector-gbk.def
%   biblatex-caspervector-utf8.def

\ProvidesFile{biblatex-caspervector-utf8.def}%
	[2015/04/28 v0.2.1 Chinese punctuations and captions in UTF-8]

\newcommand*\bbx@cnldquot{“}
\newcommand*\bbx@cnrdquot{”}
\newcommand*\bbx@cncomma{，}
\newcommand*\bbx@cnscolon{；}
\newcommand*\bbx@cncolon{：}
\newcommand*\bbx@cnperiod{。}

\DefineBibliographyStrings{english}{
	andmore = {\bbx@cegen{等}{\mkbibemph{et\addabbrvspace al\adddot}}},
	andothers = {\bbx@cegen{等}{\mkbibemph{et\addabbrvspace al\adddot}}},
	bibliography = {参考文献},
	references = {参考文献}
}

\newbibmacro*{cein:}{\printtext{\bbx@cegen{出自}{In}\bbx@cecolon}}
\newbibmacro*{cebyauthor}{%
	\ifnameundef{author}{}{%
		\bbx@cegen%
		{\printnames{author}\printtext{著}}%
		{\usebibmacro{byauthor}}%
	}%
}
\newbibmacro*{cebyeditor}{%
	\ifnameundef{editor}{}{%
		\bbx@cegen%
		{\printnames{editor}\printtext{编}}%
		{\usebibmacro{byeditor}}%
	}%
}
\newbibmacro*{cebytranslator}{%
	\ifnameundef{translator}{}{%
		\bbx@cegen%
		{\printnames{translator}\printtext{译}}%
		{\usebibmacro{bytranslator}}%
	}%
}
\renewbibmacro*{urldate}{%
	\iffieldundef{urlyear}{}{%
		\printtext{\bbx@cegen{检索于 }{retrieved on\addspace}}%
		\printurldate%
	}%
}

